==> tutti-ui-swing-1.0-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/CancelEditProtocolAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: CancelEditProtocolAction.java 349 2013-02-06 10:54:11Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/CancelEditProtocolAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.AbstractTuttiAction;
import fr.ifremer.tutti.ui.swing.TuttiScreen;

import java.awt.event.ActionEvent;

import static org.nuiton.i18n.I18n._;

/**
 * Cancels the edition of a protocol
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class CancelEditProtocolAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    private static final long serialVersionUID = 1L;

    public CancelEditProtocolAction(EditProtocolUIHandler handler) {
        super(handler,
              "cancelEditProtocol",
              "cancel",
              _("tutti.action.cancel.editProtocol"),
              _("tutti.action.cancel.editProtocol.tip"),
              true
        );
    }

    @Override
    protected void doAction(ActionEvent event) {

        getContext().setScreen(TuttiScreen.SELECT_CRUISE);
    }

}

==> tutti-ui-swing-1.0.1-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/CancelEditProtocolAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: CancelEditProtocolAction.java 349 2013-02-06 10:54:11Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/CancelEditProtocolAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.AbstractTuttiAction;
import fr.ifremer.tutti.ui.swing.TuttiScreen;

import java.awt.event.ActionEvent;

import static org.nuiton.i18n.I18n._;

/**
 * Cancels the edition of a protocol
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class CancelEditProtocolAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    private static final long serialVersionUID = 1L;

    public CancelEditProtocolAction(EditProtocolUIHandler handler) {
        super(handler,
              "cancelEditProtocol",
              "cancel",
              _("tutti.action.cancel.editProtocol"),
              _("tutti.action.cancel.editProtocol.tip"),
              true
        );
    }

    @Override
    protected void doAction(ActionEvent event) {

        getContext().setScreen(TuttiScreen.SELECT_CRUISE);
    }

}
